@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qt3drender_python.h>
 #include <pyside2_qt3dcore_python.h>
@@ -59,109 +53,114 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qabstractclipanimator.h>
-#include <qclipanimator.h>
-#include <qabstractanimation.h>
-#include <qvertexblendanimation.h>
-#include <qkeyframeanimation.h>
-#include <qmorphtarget.h>
-#include <qabstractclipblendnode.h>
-#include <qblendedclipanimator.h>
-#include <qlerpclipblend.h>
-#include <qabstractanimationclip.h>
-#include <qanimationcontroller.h>
-#include <qadditiveclipblend.h>
-#include <qanimationgroup.h>
-#include <qmorphinganimation.h>
-#include <qanimationaspect.h>
+#include <Qt3DAnimation/qabstractclipanimator.h>
+#include <Qt3DAnimation/qblendedclipanimator.h>
+#include <Qt3DAnimation/qvertexblendanimation.h>
+#include <Qt3DAnimation/qanimationcontroller.h>
+#include <Qt3DAnimation/qmorphtarget.h>
+#include <Qt3DAnimation/qabstractclipblendnode.h>
+#include <Qt3DAnimation/qclipanimator.h>
+#include <Qt3DAnimation/qadditiveclipblend.h>
+#include <Qt3DAnimation/qabstractanimationclip.h>
+#include <Qt3DAnimation/qmorphinganimation.h>
+#include <Qt3DAnimation/qlerpclipblend.h>
+#include <Qt3DAnimation/qabstractanimation.h>
+#include <Qt3DAnimation/qanimationaspect.h>
+#include <Qt3DAnimation/qanimationgroup.h>
+#include <Qt3DAnimation/qkeyframeanimation.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QT3DANIMATION_IDX                                        0
-#define SBK_QT3DANIMATION_QMORPHTARGET_IDX                           16
-#define SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX                   9
-#define SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                        10
-#define SBK_QT3DANIMATION_QABSTRACTANIMATION_IDX                     1
-#define SBK_QT3DANIMATION_QABSTRACTANIMATION_ANIMATIONTYPE_IDX       2
-#define SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX                  19
-#define SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                     17
-#define SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX              18
-#define SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                     13
-#define SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX          14
-#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX                  4
-#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX            5
-#define SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                          12
-#define SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX                   11
-#define SBK_QT3DANIMATION_QABSTRACTCLIPBLENDNODE_IDX                 6
-#define SBK_QT3DANIMATION_QADDITIVECLIPBLEND_IDX                     7
-#define SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                         15
-#define SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX                 3
-#define SBK_QT3DANIMATION_QANIMATIONASPECT_IDX                       8
-#define SBK_Qt3DAnimation_IDX_COUNT                                  20
-
+enum : int {
+    SBK_QT3DANIMATION_IDX                                    = 0,
+    SBK_QT3DANIMATION_QABSTRACTANIMATION_IDX                 = 1,
+    SBK_QT3DANIMATION_QABSTRACTANIMATION_ANIMATIONTYPE_IDX   = 2,
+    SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX             = 3,
+    SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX              = 4,
+    SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX        = 5,
+    SBK_QT3DANIMATION_QABSTRACTCLIPBLENDNODE_IDX             = 6,
+    SBK_QT3DANIMATION_QADDITIVECLIPBLEND_IDX                 = 7,
+    SBK_QT3DANIMATION_QANIMATIONASPECT_IDX                   = 8,
+    SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX               = 9,
+    SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                    = 10,
+    SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX               = 11,
+    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 12,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 13,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 14,
+    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 15,
+    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 16,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 17,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 18,
+    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 19,
+    SBK_Qt3DAnimation_IDX_COUNT                              = 20
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_Qt3DAnimationTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_Qt3DAnimationModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_Qt3DAnimationTypeConverters;
 
 // Converter indices
-#define SBK_QT3DANIMATION_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX       0 // QVector<Qt3DRender::QAttribute* >
-#define SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                       1 // const QList<QObject* > &
-#define SBK_QT3DANIMATION_QLIST_QBYTEARRAY_IDX                       2 // QList<QByteArray >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QANIMATIONGROUPPTR_IDX 3 // QVector<Qt3DAnimation::QAnimationGroup* >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX 4 // QVector<Qt3DAnimation::QAbstractAnimation* >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QNODEPTR_IDX              5 // QVector<Qt3DCore::QNode* >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QENTITYPTR_IDX            6 // QVector<Qt3DCore::QEntity* >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QMORPHTARGETPTR_IDX  7 // QVector<Qt3DAnimation::QMorphTarget* >
-#define SBK_QT3DANIMATION_QVECTOR_FLOAT_IDX                          8 // const QVector<float > &
-#define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QTRANSFORMPTR_IDX         9 // QVector<Qt3DCore::QTransform* >
-#define SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                         10 // QList<QVariant >
-#define SBK_QT3DANIMATION_QLIST_QSTRING_IDX                          11 // QList<QString >
-#define SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX                  12 // QMap<QString,QVariant >
-#define SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                       13
-
+enum : int {
+    SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                   = 0, // const QList<QObject* > &
+    SBK_QT3DANIMATION_QLIST_QBYTEARRAY_IDX                   = 1, // QList<QByteArray >
+    SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QNODEPTR_IDX          = 2, // QVector<Qt3DCore::QNode* >
+    SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QENTITYPTR_IDX        = 3, // QVector<Qt3DCore::QEntity* >
+    SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QANIMATIONGROUPPTR_IDX = 4, // QVector<Qt3DAnimation::QAnimationGroup* >
+    SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX = 5, // QVector<Qt3DAnimation::QAbstractAnimation* >
+    SBK_QT3DANIMATION_QVECTOR_FLOAT_IDX                      = 6, // QVector<float >
+    SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QTRANSFORMPTR_IDX     = 7, // QVector<Qt3DCore::QTransform* >
+    SBK_QT3DANIMATION_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX   = 8, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QMORPHTARGETPTR_IDX = 9, // QVector<Qt3DAnimation::QMorphTarget* >
+    SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                     = 10, // QList<QVariant >
+    SBK_QT3DANIMATION_QLIST_QSTRING_IDX                      = 11, // QList<QString >
+    SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX              = 12, // QMap<QString,QVariant >
+    SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                   = 13
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphTarget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHTARGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimation::AnimationType >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATION_ANIMATIONTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QVertexBlendAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation::Method >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation::RepeatMode >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimationClip >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator::Loops >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipBlendNode >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPBLENDNODE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAdditiveClipBlend >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QADDITIVECLIPBLEND_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QLerpClipBlend >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimationClip >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationAspect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONASPECT_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationController >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation::RepeatMode >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QLerpClipBlend >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphTarget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHTARGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation::Method >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QVertexBlendAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX]); }
 
 } // namespace Shiboken
 
