@@ -53,43 +53,43 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qt3dwindow.h>
-#include <qnormaldiffusemapmaterial.h>
-#include <qplanegeometry.h>
-#include <qtorusmesh.h>
-#include <qskyboxentity.h>
-#include <qspritesheet.h>
-#include <qdiffusespecularmaterial.h>
-#include <qcylindergeometry.h>
-#include <qextrudedtextmesh.h>
-#include <qplanemesh.h>
-#include <qpervertexcolormaterial.h>
-#include <qgoochmaterial.h>
-#include <qcuboidmesh.h>
-#include <qphongalphamaterial.h>
-#include <qspritegrid.h>
-#include <qorbitcameracontroller.h>
-#include <qconegeometry.h>
-#include <qtext2dentity.h>
-#include <qfirstpersoncameracontroller.h>
-#include <qextrudedtextgeometry.h>
-#include <qconemesh.h>
-#include <qphongmaterial.h>
-#include <qnormaldiffusespecularmapmaterial.h>
-#include <qabstractcameracontroller.h>
-#include <qspritesheetitem.h>
-#include <qmorphphongmaterial.h>
-#include <qforwardrenderer.h>
-#include <qspheregeometry.h>
-#include <qdiffusespecularmapmaterial.h>
-#include <qcylindermesh.h>
-#include <qabstractspritesheet.h>
-#include <qdiffusemapmaterial.h>
-#include <qcuboidgeometry.h>
-#include <qtexturematerial.h>
-#include <qspheremesh.h>
-#include <qtorusgeometry.h>
-#include <qmetalroughmaterial.h>
+#include <Qt3DExtras/qmorphphongmaterial.h>
+#include <Qt3DExtras/qspritesheet.h>
+#include <Qt3DExtras/qfirstpersoncameracontroller.h>
+#include <Qt3DExtras/qtorusgeometry.h>
+#include <Qt3DExtras/qdiffusemapmaterial.h>
+#include <Qt3DExtras/qplanemesh.h>
+#include <Qt3DExtras/qskyboxentity.h>
+#include <Qt3DExtras/qspritesheetitem.h>
+#include <Qt3DExtras/qforwardrenderer.h>
+#include <Qt3DExtras/qmetalroughmaterial.h>
+#include <Qt3DExtras/qabstractcameracontroller.h>
+#include <Qt3DExtras/qcuboidmesh.h>
+#include <Qt3DExtras/qdiffusespecularmaterial.h>
+#include <Qt3DExtras/qspritegrid.h>
+#include <Qt3DExtras/qextrudedtextgeometry.h>
+#include <Qt3DExtras/qplanegeometry.h>
+#include <Qt3DExtras/qextrudedtextmesh.h>
+#include <Qt3DExtras/qcylindergeometry.h>
+#include <Qt3DExtras/qtexturematerial.h>
+#include <Qt3DExtras/qconegeometry.h>
+#include <Qt3DExtras/qspheregeometry.h>
+#include <Qt3DExtras/qtext2dentity.h>
+#include <Qt3DExtras/qconemesh.h>
+#include <Qt3DExtras/qcuboidgeometry.h>
+#include <Qt3DExtras/qnormaldiffusemapmaterial.h>
+#include <Qt3DExtras/qspheremesh.h>
+#include <Qt3DExtras/qgoochmaterial.h>
+#include <Qt3DExtras/qtorusmesh.h>
+#include <Qt3DExtras/qpervertexcolormaterial.h>
+#include <Qt3DExtras/qcylindermesh.h>
+#include <Qt3DExtras/qphongalphamaterial.h>
+#include <Qt3DExtras/qt3dwindow.h>
+#include <Qt3DExtras/qdiffusespecularmapmaterial.h>
+#include <Qt3DExtras/qnormaldiffusespecularmapmaterial.h>
+#include <Qt3DExtras/qabstractspritesheet.h>
+#include <Qt3DExtras/qphongmaterial.h>
+#include <Qt3DExtras/qorbitcameracontroller.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
