@@ -51,41 +51,41 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <q3dbars.h>
-#include <qbardataproxy.h>
-#include <qsurfacedataitem.h>
-#include <qabstractdataproxy.h>
-#include <qcustom3dvolume.h>
-#include <qbardataitem.h>
-#include <qitemmodelsurfacedataproxy.h>
-#include <q3dtheme.h>
-#include <q3dscene.h>
-#include <qscatterdataproxy.h>
-#include <qlogvalue3daxisformatter.h>
-#include <q3dsurface.h>
-#include <qcategory3daxis.h>
-#include <qitemmodelbardataproxy.h>
-#include <qabstract3dgraph.h>
-#include <qscatterdataitem.h>
-#include <q3dinputhandler.h>
-#include <q3dscatter.h>
-#include <q3dlight.h>
-#include <qcustom3ditem.h>
-#include <qitemmodelscatterdataproxy.h>
-#include <qsurface3dseries.h>
-#include <qabstract3dinputhandler.h>
-#include <qabstract3dseries.h>
-#include <qbar3dseries.h>
-#include <q3dobject.h>
-#include <qabstract3daxis.h>
-#include <qvalue3daxis.h>
-#include <q3dcamera.h>
-#include <qcustom3dlabel.h>
-#include <qtouch3dinputhandler.h>
-#include <qvalue3daxisformatter.h>
-#include <qsurfacedataproxy.h>
-#include <qheightmapsurfacedataproxy.h>
-#include <qscatter3dseries.h>
+#include <QtDataVisualization/qscatterdataitem.h>
+#include <QtDataVisualization/qabstract3daxis.h>
+#include <QtDataVisualization/qvalue3daxis.h>
+#include <QtDataVisualization/q3dscatter.h>
+#include <QtDataVisualization/qabstractdataproxy.h>
+#include <QtDataVisualization/qsurfacedataproxy.h>
+#include <QtDataVisualization/qcustom3dlabel.h>
+#include <QtDataVisualization/qabstract3dinputhandler.h>
+#include <QtDataVisualization/qtouch3dinputhandler.h>
+#include <QtDataVisualization/qbardataproxy.h>
+#include <QtDataVisualization/q3dbars.h>
+#include <QtDataVisualization/qheightmapsurfacedataproxy.h>
+#include <QtDataVisualization/qsurface3dseries.h>
+#include <QtDataVisualization/q3dobject.h>
+#include <QtDataVisualization/qscatterdataproxy.h>
+#include <QtDataVisualization/qbardataitem.h>
+#include <QtDataVisualization/q3dcamera.h>
+#include <QtDataVisualization/qvalue3daxisformatter.h>
+#include <QtDataVisualization/qcustom3dvolume.h>
+#include <QtDataVisualization/qitemmodelsurfacedataproxy.h>
+#include <QtDataVisualization/qscatter3dseries.h>
+#include <QtDataVisualization/q3dtheme.h>
+#include <QtDataVisualization/q3dscene.h>
+#include <QtDataVisualization/qcategory3daxis.h>
+#include <QtDataVisualization/qitemmodelbardataproxy.h>
+#include <QtDataVisualization/qcustom3ditem.h>
+#include <QtDataVisualization/q3dinputhandler.h>
+#include <QtDataVisualization/q3dlight.h>
+#include <QtDataVisualization/qsurfacedataitem.h>
+#include <QtDataVisualization/qabstract3dseries.h>
+#include <QtDataVisualization/q3dsurface.h>
+#include <QtDataVisualization/qbar3dseries.h>
+#include <QtDataVisualization/qitemmodelscatterdataproxy.h>
+#include <QtDataVisualization/qlogvalue3daxisformatter.h>
+#include <QtDataVisualization/qabstract3dgraph.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
