@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtscript_python.h>
 #include <pyside2_qtcore_python.h>
@@ -59,46 +53,51 @@
 #include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qscriptenginedebugger.h>
+#include <QtScriptTools/qscriptenginedebugger.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QSCRIPTENGINEDEBUGGER_IDX                                0
-#define SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX                 3
-#define SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX                 1
-#define SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX                  2
-#define SBK_QtScriptTools_IDX_COUNT                                  4
-
+enum : int {
+    SBK_QSCRIPTENGINEDEBUGGER_IDX                            = 0,
+    SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX             = 3,
+    SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX             = 1,
+    SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX              = 2,
+    SBK_QtScriptTools_IDX_COUNT                              = 4
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtScriptToolsTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtScriptToolsModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtScriptToolsTypeConverters;
 
 // Converter indices
-#define SBK_QTSCRIPTTOOLS_QLIST_QOBJECTPTR_IDX                       0 // const QList<QObject* > &
-#define SBK_QTSCRIPTTOOLS_QLIST_QBYTEARRAY_IDX                       1 // QList<QByteArray >
-#define SBK_QTSCRIPTTOOLS_QLIST_QVARIANT_IDX                         2 // QList<QVariant >
-#define SBK_QTSCRIPTTOOLS_QLIST_QSTRING_IDX                          3 // QList<QString >
-#define SBK_QTSCRIPTTOOLS_QMAP_QSTRING_QVARIANT_IDX                  4 // QMap<QString,QVariant >
-#define SBK_QtScriptTools_CONVERTERS_IDX_COUNT                       5
-
+enum : int {
+    SBK_QTSCRIPTTOOLS_QLIST_QOBJECTPTR_IDX                   = 0, // const QList<QObject* > &
+    SBK_QTSCRIPTTOOLS_QLIST_QBYTEARRAY_IDX                   = 1, // QList<QByteArray >
+    SBK_QTSCRIPTTOOLS_QLIST_QVARIANT_IDX                     = 2, // QList<QVariant >
+    SBK_QTSCRIPTTOOLS_QLIST_QSTRING_IDX                      = 3, // QList<QString >
+    SBK_QTSCRIPTTOOLS_QMAP_QSTRING_QVARIANT_IDX              = 4, // QMap<QString,QVariant >
+    SBK_QtScriptTools_CONVERTERS_IDX_COUNT                   = 5
+};
 // Macros for type check
 
 namespace Shiboken
