@@ -52,10 +52,10 @@
 #include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qtestmouse.h>
-#include <qtestkeyboard.h>
-#include <qttestglobal.h>
-#include <qbenchmarkmetric.h>
+#include <QtTest/qtestmouse.h>
+#include <QtTest/qttestglobal.h>
+#include <QtTest/qbenchmarkmetric.h>
+#include <QtTest/qtestkeyboard.h>
 #include <pysideqtesttouch.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
