@@ -50,12 +50,13 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qwebengineurlschemehandler.h>
-#include <qwebenginehttprequest.h>
-#include <qwebengineurlrequestjob.h>
-#include <qwebengineurlrequestinterceptor.h>
-#include <qwebengineurlrequestinfo.h>
-#include <qwebenginecookiestore.h>
+#include <QtWebEngineCore/qwebengineurlrequestinfo.h>
+#include <QtWebEngineCore/qwebengineurlschemehandler.h>
+#include <QtWebEngineCore/qwebengineurlscheme.h>
+#include <QtWebEngineCore/qwebenginecookiestore.h>
+#include <QtWebEngineCore/qwebengineurlrequestjob.h>
+#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
+#include <QtWebEngineCore/qwebenginehttprequest.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -76,17 +77,22 @@
 
 // Type indices
 enum : int {
-    SBK_QWEBENGINECOOKIESTORE_IDX                            = 0,
-    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 1,
-    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 2,
-    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 3,
-    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 5,
-    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 4,
-    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 6,
-    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 7,
-    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 8,
-    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 9,
-    SBK_QtWebEngineCore_IDX_COUNT                            = 10
+    SBK_QWEBENGINECOOKIESTORE_IDX                            = 1,
+    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 2,
+    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 3,
+    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 4,
+    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 6,
+    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 5,
+    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 7,
+    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 8,
+    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 9,
+    SBK_QWEBENGINEURLSCHEME_IDX                              = 10,
+    SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX                       = 13,
+    SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX                  = 12,
+    SBK_QWEBENGINEURLSCHEME_FLAG_IDX                         = 11,
+    SBK_QFLAGS_QWEBENGINEURLSCHEME_FLAG_IDX                  = 0,
+    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 14,
+    SBK_QtWebEngineCore_IDX_COUNT                            = 15
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtWebEngineCoreTypes;
@@ -123,6 +129,11 @@ template<> inline PyTypeObject* SbkType< ::QWebEngineUrlRequestInfo >() { return
 template<> inline PyTypeObject* SbkType< ::QWebEngineUrlRequestInterceptor >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QWebEngineUrlRequestJob::Error >() { return SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QWebEngineUrlRequestJob >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLREQUESTJOB_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QWebEngineUrlScheme::Syntax >() { return SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebEngineUrlScheme::SpecialPort >() { return SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebEngineUrlScheme::Flag >() { return SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLSCHEME_FLAG_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<QWebEngineUrlScheme::Flag> >() { return SbkPySide2_QtWebEngineCoreTypes[SBK_QFLAGS_QWEBENGINEURLSCHEME_FLAG_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebEngineUrlScheme >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLSCHEME_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QWebEngineUrlSchemeHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineCoreTypes[SBK_QWEBENGINEURLSCHEMEHANDLER_IDX]); }
 
 } // namespace Shiboken
